module.exports = function( grunt ) {
	'use strict';

	// Project configuration
	grunt.initConfig( {
		pkg:    grunt.file.readJSON( 'package.json' ),
		concat: {
			options: {
				stripBanners: true,
				banner: '/*! <%= pkg.title %> - v<%= pkg.version %> - <%= grunt.template.today("yyyy-mm-dd") %>\n' +
					' * <%= pkg.homepage %>\n' +
					' * Copyright (c) <%= grunt.template.today("yyyy") %>;' +
					' * Licensed GPLv2+' +
					' */\n'
			},
			twenty_eleven_art_gallery: {
				src: [
					'assets/build/twenty_eleven_art_gallery_templates.js',
					'assets/js/src/artwork_models.js',
					'assets/js/src/artwork_views.js',
					'assets/js/src/twenty_eleven_art_gallery.js'
				],
				dest: 'assets/build/twenty_eleven_art_gallery.js'
			}
		},
		jshint: {
			all: [
				'Gruntfile.js',
				'assets/js/src/**/*.js',
				'assets/js/test/**/*.js'
			],
			options: {
        jshintrc: '.jshintrc'
			}
		},
		jst: {
			options: {
				namespace: 'artgallery',
				prettify: true
			},
			compile: {
				files: {
					'assets/build/twenty_eleven_art_gallery_templates.js': ['assets/js/templates/**/*.tmpl']
				}
			}
		},
		uglify: {
			all: {
				files: {
					'assets/build/twenty_eleven_art_gallery.min.js': ['assets/build/twenty_eleven_art_gallery.js']
				},
				options: {
					banner: '/*! <%= pkg.title %> - v<%= pkg.version %> - <%= grunt.template.today("yyyy-mm-dd") %>\n' +
						' * <%= pkg.homepage %>\n' +
						' * Copyright (c) <%= grunt.template.today("yyyy") %>;' +
						' * Licensed GPLv2+' +
						' */\n',
					mangle: {
						except: ['jQuery']
					}
				}
			}
		},
		test:   {
			files: ['assets/js/test/**/*.js']
		},
		sass:   {
			all: {
				files: {
					'assets/build/twenty_eleven_art_gallery.css': 'assets/css/sass/twenty_eleven_art_gallery.scss'
				}
			}
		},
		cssmin: {
			options: {
				banner: '/*! <%= pkg.title %> - v<%= pkg.version %> - <%= grunt.template.today("yyyy-mm-dd") %>\n' +
					' * <%= pkg.homepage %>\n' +
					' * Copyright (c) <%= grunt.template.today("yyyy") %>;' +
					' * Licensed GPLv2+' +
					' */\n'
			},
			minify: {
				expand: true,

				cwd: 'assets/build/',
				src: ['twenty_eleven_art_gallery.css'],

				dest: 'assets/build/',
				ext: '.min.css'
			}
		},
		watch:  {

			sass: {
				files: ['assets/css/sass/*.scss'],
				tasks: ['sass', 'cssmin'],
				options: {
					debounceDelay: 500
				}
			},

			scripts: {
				files: ['assets/js/src/**/*.js', 'assets/js/vendor/**/*.js'],
				tasks: ['jshint', 'concat', 'uglify'],
				options: {
					debounceDelay: 500
				}
			},

			template: {
				files: ['assets/js/src/**/*.tmpl'],
				tasks: ['jst', 'concat', 'uglify'],
				options: {
					debounceDelay: 500
				}
			}
		}
	} );

	// Load other tasks
	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-jst');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-cssmin');

	grunt.loadNpmTasks('grunt-contrib-sass');

	grunt.loadNpmTasks('grunt-contrib-watch');

	// Default task.

	grunt.registerTask( 'default', ['jshint', 'jst', 'concat', 'uglify', 'sass', 'cssmin'] );

	grunt.util.linefeed = '\n';
};